pub struct LocalBins {
pub dir: PathBuf,
pub cli: PathBuf,
pub tui: PathBuf,
pub status_api: PathBuf,
pub mcp: Option<PathBuf>,
}Expand description
Paths to box binaries after cache extract or --bin-dir.
Fields
dir: PathBufDirectory that contains the binaries (source or install layout).
cli: PathBufCLI apply agent.
tui: PathBufTUI binary.
status_api: PathBufStatus API binary.
mcp: Option<PathBuf>MCP server binary when present in the Release / bin dir.